# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jetpack/proto/runtime/v1alpha1/app.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from jetpack.proto.runtime.v1alpha1 import remote_pb2 as jetpack_dot_proto_dot_runtime_dot_v1alpha1_dot_remote__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(jetpack/proto/runtime/v1alpha1/app.proto\x12\x07userapp\x1a+jetpack/proto/runtime/v1alpha1/remote.proto\"\xd9\x01\n\x07UserApp\x12^\n\x14revision_to_manifest\x18\x01 \x03(\x0b\x32(.userapp.UserApp.RevisionToManifestEntryB\x02\x18\x01R\x12revisionToManifest\x12\'\n\x0flatest_manifest\x18\x02 \x01(\tR\x0elatestManifest\x1a\x45\n\x17RevisionToManifestEntry\x12\x10\n\x03key\x18\x01 \x01(\x04R\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x87\x01\n\x0b\x63om.userappB\x08\x41ppProtoP\x01Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\xa2\x02\x03UXX\xaa\x02\x07Userapp\xca\x02\x07Userapp\xe2\x02\x13Userapp\\GPBMetadata\xea\x02\x07Userappb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jetpack.proto.runtime.v1alpha1.app_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\013com.userappB\010AppProtoP\001Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\242\002\003UXX\252\002\007Userapp\312\002\007Userapp\342\002\023Userapp\\GPBMetadata\352\002\007Userapp'
  _USERAPP_REVISIONTOMANIFESTENTRY._options = None
  _USERAPP_REVISIONTOMANIFESTENTRY._serialized_options = b'8\001'
  _USERAPP.fields_by_name['revision_to_manifest']._options = None
  _USERAPP.fields_by_name['revision_to_manifest']._serialized_options = b'\030\001'
  _USERAPP._serialized_start=99
  _USERAPP._serialized_end=316
  _USERAPP_REVISIONTOMANIFESTENTRY._serialized_start=247
  _USERAPP_REVISIONTOMANIFESTENTRY._serialized_end=316
# @@protoc_insertion_point(module_scope)
